<!--
 * @Author: 823042332@qq.com 823042332@qq.com
 * @Date: 2025-04-15 23:08:16
 * @LastEditors: 823042332@qq.com 823042332@qq.com
 * @LastEditTime: 2025-09-03 11:14:51
 * @FilePath: /llmada/README.md
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
-->
# llmada
一个方便使用各种LLM api的工具
不受VPN影响
